"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAuthProvider = void 0;
const createAuthProvider = (integration) => {
    const context = {
        isAuthenticated: false,
    };
    return {
        signIn: (username, password) => __awaiter(void 0, void 0, void 0, function* () {
            const result = yield integration.signIn(username, password);
            yield integration.updateSecurityContext(context);
            context.isAuthenticated = result.success;
            return result;
        }),
        signOut: () => __awaiter(void 0, void 0, void 0, function* () {
            const result = yield integration.signOut();
            yield integration.updateSecurityContext(context);
            context.isAuthenticated = !result.success;
            return result;
        }),
        context,
        isAuthenticated: context.isAuthenticated,
        signUp: (username, password, email) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.signUp(username, password, email);
        }),
        lockAccount: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.lockAccount(username);
        }),
        resetPassword: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.resetPassword(username);
        }),
        confirmSignUp: (username, code) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.confirmSignUp(username, code);
        }),
        resendSignUp: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.resendSignUp(username);
        }),
        forgotPassword: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.forgotPassword(username);
        }),
        forgotPasswordConfirmationCode: (username, code, newPassword) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.forgotPasswordConfirmationCode(username, code, newPassword);
        }),
        lockSession: () => __awaiter(void 0, void 0, void 0, function* () {
            return integration.lockSession();
        }),
        unlockSession: () => __awaiter(void 0, void 0, void 0, function* () {
            return integration.unlockSession();
        }),
        unlockAccount: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.unlockAccount(username);
        }),
        disableAccount: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.disableAccount(username);
        }),
        enableAccount: (username) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.enableAccount(username);
        }),
        refreshToken: () => __awaiter(void 0, void 0, void 0, function* () {
            return integration.refreshToken();
        }),
        hasPermission: (permission) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.hasPermission(permission);
        }),
        definePermission: (permission) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.definePermission(permission);
        }),
        validatePermission: (permission) => {
            return integration.validatePermission(permission);
        },
        defineRole: (role, permissions) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.defineRole(role, permissions);
        }),
        assignRole: (username, role) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.assignRole(username, role);
        }),
        hasRole: (username, role) => __awaiter(void 0, void 0, void 0, function* () {
            return integration.hasRole(username, role);
        }),
        addCustomClaim: (claim, value) => {
            integration.addCustomClaim(claim, value);
        },
    };
};
exports.createAuthProvider = createAuthProvider;
